#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 safecopy
version:              0.10.4.3
visibility:           public
id:                   safecopy-0.10.4.3-GxsGQnLXMqTKzg7pRmTy0z
key:                  safecopy-0.10.4.3-GxsGQnLXMqTKzg7pRmTy0z
license:              LicenseRef-PublicDomain
maintainer:           Lemmih <lemmih@gmail.com>, David Fox <dsf@seereason.com>
author:               David Himmelstrup, Felipe Lessa
homepage:             https://github.com/acid-state/safecopy
synopsis:             Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.

category:             Data, Parsing
abi:                  a2546122fc1c52f19a6149288bffc3fd
exposed:              True
exposed-modules:      Data.SafeCopy Data.SafeCopy.Internal
hidden-modules:
    Data.SafeCopy.Instances Data.SafeCopy.SafeCopy Data.SafeCopy.Derive

import-dirs:          /usr/lib/ghc-9.6.6/site-local/safecopy-0.10.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/safecopy-0.10.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/safecopy-0.10.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-safecopy
hs-libraries:         HSsafecopy-0.10.4.3-GxsGQnLXMqTKzg7pRmTy0z
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK containers-0.6.7
    generic-data-1.1.0.2-FLnFwzgXSj5FClDvcqzMIp
    old-time-1.1.0.5-6pAIdwhrU2yDlFeoj1dxmG template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    vector-0.13.2.0-7eILYIgfGZSAohY3MIpZY

haddock-interfaces:   /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html:         /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

